; Leptospirosis in Marginalized Urban Communities
globals
[
  cum-human-pop
  cum-dog-pop                                  ;added for sensitivity analysis
  cum-rodent-pop                               ;added for sensitivity analysis
  ann-human-dl-inc-per10000
  cum-ann-human-dl-inc
  ann-human-rl-inc-per10000
  cum-ann-human-rl-inc
  cum-ann-dog-dl-inc                           ;added for sa
  cum-ann-dog-rl-inc                           ;added for sa
  ann-dog-dl-inc                               ;added for sa
  ann-dog-rl-inc                               ;added for sa
  cum-ann-rod-rl-inc
  cum-ann-rod-dl-inc
  ann-rod-rl-inc                               ;added for sa
  ann-rod-dl-inc                               ;added for sa
  vhh                                          ;vacant household (designate a potential dog-owning household)
  new-amt-shed
  patch-visited
  hp-rl
  nhp-rl
  patch-visited-rl
  patch-visited-n-rl
  hp-dl
  nhp-dl
  patch-visited-dl
  patch-visited-n-dl
]
breed [ rodents rodent ]
breed [ dogs dog ]
breed [ humans human ]
patches-own
[
  hh-id                                           ;household id, 0 if not a household patch
  num-humans                                      ;number of humans on hh patch
  num-odogs-here                                  ;max number of owned dogs on this patch
  dcc
  c-acc                                           ;current accomodation potential for dogs
  p-inf-rod                                       ;probability that a host on the patch would be infected with the rodent serovar
  p-inf-dog                                       ;probability that a host on the patch would be infected with the dog serovar
  e-amount-seroR                                  ;total number of rodent serovar leptospires on patch
  e-amount-seroD                                  ;total number of dog serovar leptospires on patch
]
rodents-own
[
  r-start-patch                                   ;the center of the rodents' homerange
  r-age                                           ;rodent age for juvenile or adult
  r-immune-status                                 ;$ ss rod-S dog-S ; si rod-S dog-I; sshed rod-S dog-Shed; sr rod-S dog-R; is rod-I dog-S; sheds rod-Shed dog-S; rs rod-R dog-S
  r-days-incub-rod
  r-days-shed-rod
  r-days-incub-dog
  r-days-shed-dog
  r-days-recovered
  r-trans-prob
  d-trans-prob
]
dogs-own
[
  status                                           ;0 owned/ 1 stray
  start-patch                                      ;the center of the dogs' homerange
  age
  d-immune-status                                  ;ss rod-S dog-S ; si rod-S dog-I; sshed rod-S dog-Shed; sr rod-S dog-R; is rod-I dog-S; sheds rod-Shed dog-S; rs rod-R dog-S
  d-days-incub-rod
  d-days-shed-rod
  d-days-incub-dog
  d-days-shed-dog
  d-days-recovered
  r-trans-prob
  d-trans-prob
  d-death-prob
  sus                                             ;to simulate differntial susceptibility
]
humans-own
[
  h-immune-status                                 ;ss rod-S dog-S; is rod-I dog-S; rs rod-R dog-S; si rod-S dog-I; sr rod-S dog-R
  h-days-inf-rod
  h-days-inf-dog
]

to setup
  ca
  ask patches [
    set num-odogs-here -1
    set hh-id 0
    set c-acc 0
    ]
  let patch-cx max [pxcor] of patches / 2
  let patch-cy max [pycor] of patches / 2
  let num-hh 0
  ask patch patch-cx patch-cy [
    ask n-of num-households patches with [ hh-id = 0 ] in-radius hh-area [
      set pcolor yellow
      let nx round random-normal 4 2
      if nx < 0 [set nx 0 ]
      set num-humans 1 + nx
      set hh-id num-hh + 1
      set num-hh num-hh + 1
      ]
    ]
  let household-patches patches with [ hh-id > 0 and  num-odogs-here = -1 ]
  let tot-hhp count household-patches
  ask n-of round (0.47 * tot-hhp) household-patches [ set num-odogs-here 0 ]
  ask n-of round (0.27 * tot-hhp) household-patches [ set num-odogs-here 1 ]
  ask n-of round (0.11 * tot-hhp) household-patches [ set num-odogs-here 2 ]
  ask n-of round (0.08 * tot-hhp) household-patches [ set num-odogs-here 3 ]
  ask n-of round (0.06 * tot-hhp) household-patches [ set num-odogs-here 4 ]
  ask n-of round (0.03 * tot-hhp) household-patches [ set num-odogs-here 5 ]
  ask household-patches [
    ask patches with [ hh-id = 0 ] in-radius (1 + random community-size) [
      set hh-id -2                                                             ; slum area
      set pcolor brown + 1
      ]
    ]
  ask household-patches [
    ask patches with [hh-id = -2 ] in-radius 1.5 [                             ;household area around each hh
      set hh-id -1
      set pcolor brown
      ]
    ]

  ask patches with [ hh-id != 0 ][
    set dcc pcc
  ]

  create-dogs (od-init + sd-init) [ ;carrying capacity
    ifelse random-float 1 < 0.51    ; 1:1 stray:owned dogs ratio
    [ set status 0 ]                ; owned
    [ set status 1 ]                ; stray
    set shape "wolf"
    set color grey - 2
    set size 1
    set age random 53
    set d-immune-status "ss"
    set d-days-shed-dog 0
    set d-days-shed-rod 0
    set d-days-incub-dog 0
    set d-days-incub-rod 0
    set sus 0
    set d-trans-prob 0
    set r-trans-prob 0
    ]
  ask patches with [ hh-id > 0 ][
    sprout-humans num-humans
    [ set shape "person"
      set color blue
      set size 2
      set h-immune-status "ss"
      set h-days-inf-dog 0
      set h-days-inf-rod 0
      ]
    ]
  let odog-patches patches with [ num-odogs-here > 0 ]
  ask odog-patches [
    let av-odogs dogs with [ status = 0 and size = 1 ]
    let num-av-patches count patches with [ dcc > 0 ] in-radius 5
    if floor (num-av-patches / num-odogs-here) > dsp [                            ; 9 patches required for supporting 1 dog
      if (num-odogs > 0) [
        ifelse (count av-odogs >= num-odogs-here)
        [ ask n-of num-odogs-here av-odogs [
          set size 3
          setxy [ pxcor ] of myself [ pycor ] of myself
          set start-patch myself
          if (age > 24) [
            change-av-dogs
            ]
          ]
          ]
        [ ask av-odogs [
          set size 3
          setxy [ pxcor ] of myself [ pycor ] of myself
          set start-patch myself
          if (age > 24 ) [
            change-av-dogs
            ]
          ]
          ]
        ]
      ]
    ]
  if any? dogs with [ status = 0 and size = 1 ][
   ask dogs with [ status = 0 and size = 1 ][
      move-to one-of patches with [ c-acc > 0 and hh-id = -1]
      if age > 24 [
        change-av-dogs
        ]
      set size 3
      let xhere [ pxcor ] of patch-here
      let yhere [ pycor ] of patch-here
      set start-patch  patch xhere yhere
      ]
    ]
  ask patches with [ hh-id != 0 ][
    chk-av-dogs
    ]
  ask dogs with [ status = 1 and size = 1 ][
    find-sdog-hp
    set size 3
    ]
  if r-init != 0 [
    create-rodents r-init [
      set shape "default"
      set color white
      set size 1
      let id (1 + random 150)
      let r-homepatch one-of patches with [ hh-id = id ]
      setxy ([ pxcor ] of r-homepatch) ([ pycor ] of r-homepatch)
      set r-start-patch one-of patches in-radius 1.5
      move-to r-start-patch
      set r-age random 17
      set r-immune-status "ss"
      set r-days-incub-rod 0
      set r-days-shed-rod 0
      set r-days-incub-dog 0
      set r-days-shed-dog 0
      ]
    ]
  if (Output_file? = "YES") [
    if (file-exists? (word "results/HostLeptoIncidence.csv") = FALSE)[
      file-open (word "results/HostLeptoIncidence.csv")
      file-print "d-d-t,r-r-t,decay-factor,Year,HumanAnnualDogSerovarInc/10K,HumanAnnualRodentSerovarInc/10K,DogAnnualDLCases,DogAnnualRLCases,RodentAnnualRLCases,RodentAnnualDLCases"
      file-close
    ]
    ]
  reset-ticks
end

to go
  if (ticks = 0) [
    ask humans [ ht ]
    ]
  if (year = 9) [ stop ] ; year = 12 to 9
;  if ticks = 0 [                                        ;commented out: because this results in spurious output for year 3
;    set cum-human-pop cum-human-pop + count humans
;    ]
  if (week mod 4 = 0 and week < 52) [
    set cum-human-pop cum-human-pop + count humans
    set cum-dog-pop cum-dog-pop + count dogs             ;added for sa
    set cum-rodent-pop cum-rodent-pop + count rodents    ;added for sa
    ]
  if (year = 2 and week = 1) [
    ;export-world "mhms.csv"
    ask dogs with [ status = 0 ] [
      if random-float 1 < od-init-prev [
        ifelse random 100 < 51
        [ set d-immune-status "sshed"
          set d-days-shed-dog random 13 ]
        [ set d-immune-status "sr" ]
        ]
      ]
    ask dogs with [ status = 1 ] [
    if (random-float 1 < sd-init-prev ) [
        ifelse random 100 < 51
        [ set d-immune-status "sshed"
          set d-days-shed-dog random 13 ]
        [ set d-immune-status "sr" ]
        ]
      ]
    ask rodents [
      if random-float 1 < r-init-prev [
        ifelse random 100 < 81
        [ set r-immune-status "sheds" ]
        [ set r-immune-status "is" ]
        ]
      ]
    ]
   if year = 3 and week = 1 [                                    ;added for sa
    set cum-human-pop 0
    set cum-dog-pop 0                                            ;added for sa
    set cum-rodent-pop 0                                         ;added for sa
    set cum-ann-human-dl-inc 0
    set cum-ann-human-rl-inc 0
    set cum-ann-dog-dl-inc 0                                     ;added for sa
    set cum-ann-dog-rl-inc 0
    set cum-ann-rod-rl-inc 0
    set cum-ann-rod-dl-inc 0
    ]
  if year > 3 and  week = 1 [
    set ann-human-dl-inc-per10000 round ((cum-ann-human-dl-inc / avg-annual-human-pop) * 10000)
    set ann-human-rl-inc-per10000 round ((cum-ann-human-rl-inc / avg-annual-human-pop) * 10000)
    set ann-dog-dl-inc precision (cum-ann-dog-dl-inc / avg-annual-dog-pop) 2   ;added for sa
    set ann-dog-rl-inc precision (cum-ann-dog-rl-inc / avg-annual-dog-pop) 2   ;added for sa
    set ann-rod-rl-inc precision (cum-ann-rod-rl-inc / avg-annual-rodent-pop) 2
    set ann-rod-dl-inc precision (cum-ann-rod-dl-inc / avg-annual-rodent-pop) 2
    if (Output_file? = "YES") [
      file-open (word "results/HostLeptoIncidence.csv")
      file-type dog-dog-transmission file-type "," file-type rodent-rodent-transmission file-type "," file-type decay-factor file-type "," file-type (year - 1) file-type "," file-type ann-human-dl-inc-per10000 file-type "," file-type ann-human-rl-inc-per10000 file-type "," file-type cum-ann-dog-dl-inc file-type "," file-type cum-ann-dog-rl-inc file-type "," file-type cum-ann-rod-rl-inc file-type "," file-type cum-ann-rod-dl-inc
      file-print""
      file-close
      ]
    set cum-human-pop 0
    set cum-dog-pop 0                                         ;added for sa
    set cum-rodent-pop 0                                      ;added for sa
    set cum-ann-human-dl-inc 0
    set cum-ann-human-rl-inc 0
    set cum-ann-dog-dl-inc 0                                 ;added for sa
    set cum-ann-dog-rl-inc 0
    set cum-ann-rod-rl-inc 0
    set cum-ann-rod-dl-inc 0
    ]
  ask dogs with [ status = 0 ][
    od-die
    od-birth
    set age age + 1
    if (age = 24) [
      if count dogs with [ status = 0 and age > 24 ] < od-init [
        set vhh 0
        find-dohh
        ifelse vhh > 0
        [ move-to one-of patches with [ hh-id = vhh ]
          change-av-dogs
          set start-patch patch-here
          ]
        [ set status 1
          set shape "wolf"
          set start-patch patch-here
          find-sdog-hp
          set sus sdog-addl-sus
          ]
        ]
      ]
    ]
  ask dogs with [ status = 1 ][
    sd-die
    sd-birth
    set age age + 1
    if age = 24 [
      ask patch-here [
        chk-av-dogs
        ifelse c-acc > 0
        [ change-av-dogs ]
        [ ask myself [ find-sdog-hp ] ]
        ]
      ]
    ]
  ask rodents [
    r-die
    r-birth
    set r-age (r-age + 1)
    ]
  ask humans [
    h-die
    h-birth
    ]
  if (ticks > 51) [ ;259 changed to 51
    inf-dynamics
  ]
;----------------------------------Incidence in humans-------------------
  set-current-plot "Human_Lepto_incidence"
  set-current-plot-pen "SeroD"
  plotxy ticks human-dl-inc
  set-current-plot-pen "SeroR"
  plotxy ticks human-rl-inc
;-----------------------------------Prevalence in humans----------------
  set-current-plot "Human_Lepto_prevalence"
  set-current-plot-pen "SeroD"
  plotxy ticks human-dl-pre
  set-current-plot-pen "SeroR"
  plotxy ticks human-rl-pre
;-------------------------------Prevalence in dogs-------------------
  set-current-plot "StrayDog_Lepto_prevalence"
  set-current-plot-pen "SeroD"
  plotxy ticks sdog-dl-pre
  set-current-plot-pen "SeroR"
  plotxy ticks sdog-rl-pre
;-------------------------------
  set-current-plot "OwnedDog_Lepto_prevalence"
  set-current-plot-pen "SeroD"
  plotxy ticks odog-dl-pre
  set-current-plot-pen "SeroR"
  plotxy ticks odog-rl-pre
;-----------------------rodents---------------------------------------; ONCE INFECTED WITH RODENT SEROVAR, RODENTS ARE PERMANENTLY INFECTED
  set-current-plot "Rodents_Lepto_prevalence"
  set-current-plot-pen "SeroD"
  plotxy ticks rodent-dl-pre
  set-current-plot-pen "SeroR"
  plotxy ticks rodent-rl-pre
  tick
end

to inf-dynamics
  repeat 7 [
    ask dogs [ d-get-infected ]
    ask rodents [ r-get-infected ]
    ask humans [ h-get-infected ]
    ask patches [ e-decay ]
    ]
end

to change-av-dogs                     ;change patch availability
  ask n-of dsp patches with [ dcc > 0 ] in-radius 5 [
    set dcc 0
    ask patches with [ hh-id != 0 ] in-radius 5 [
      chk-av-dogs
      ]
    ]
end

to chk-av-dogs                      ;how many dogs can be supported ; 9 patches required for supporting 1 dog
  let num-av-patches count patches with [ dcc > 0 ] in-radius 5
  set c-acc floor (num-av-patches / dsp)
end

to find-dohh
  let household-patches patches with [ hh-id > 0 and  num-odogs-here > 0 ]
  let tot-hhp count household-patches
  let counter 0
  while [ vhh = 0 and counter < round (0.25 * tot-hhp) ]
  [ask n-of round (0.25 * tot-hhp) household-patches [
    if count dogs-here with [status = 0 ] < num-odogs-here and c-acc > 0 [
      set vhh hh-id
      ]
    set counter counter + 1
    ]
    ]
end

to find-sdog-hp
  let xx 0
  let sel-patch-final nobody
  while [ xx = 0 ]
  [ let num-hha-patches round (0.1 * count patches with [ hh-id = -1 ])
    let xx1 0
    while [ xx1 < num-hha-patches ]
    [ let sel-patch one-of patches with [ hh-id = -1 ]
      ask sel-patch [
        chk-av-dogs
        if (c-acc > 0) [
          set sel-patch-final sel-patch
          set xx 1
          set xx1 num-hha-patches
        ]
        set xx1 xx1 + 1
      ]
    ]
    let sel-patch one-of patches with [ hh-id != 0 ]
    ask sel-patch [
      chk-av-dogs
      if (c-acc > 0) [
        set sel-patch-final sel-patch
        set xx 1
        ]
      ]
    ]
  move-to sel-patch-final
  let aquire-patches patches with [ dcc > 0 ] in-radius 5
  if age > 24 [
   ask patch-here [
      change-av-dogs
      ]
    ]
  let xhere [ pxcor ] of patch-here
  let yhere [ pycor ] of patch-here
  set start-patch  patch xhere yhere
end
;---------- OWNED DOGS -----------
to od-die
  let ad-mor  precision ((d-death-prob + d-mortality) * (num-odogs / od-init)) 2 * 100
  let ju-mor precision ((d-death-prob + d-mortality) * 1 * (num-odogs / od-init)) 2 * 100
  ifelse age > 24
  [ if random 100 < ad-mor + 1 [
      ask patch-here [
        ask min-n-of dsp patches with [ hh-id != 0 and dcc = 0 ] [ distance myself ] [
        set dcc pcc
        chk-av-dogs
        ]
      ]
    die
    ]
    ]
  [ if random 100 < ju-mor + 1 [
    die
    ]
  ]
end
to od-birth
  if week >= 37 and week <= 52 [
    if age > 52 [
      if (random-float 1 < d-birth-prob * (od-init  / num-odogs)) [
        hatch 1 [
          set status 0
          set shape "wolf"
          set color grey - 2
          set size 3
          set age 0
          set start-patch patch-here
          set d-immune-status "ss"
          set d-days-shed-dog 0
          set d-days-shed-rod 0
          set d-days-incub-dog 0
          set d-days-incub-rod 0
          set sus 0
          ]
        ]
      ]
    ]
end
;-------- STRAY DOGS -----------------
to sd-die
  let ad-mor  precision ((d-death-prob + d-mortality) * (num-sdogs / sd-init)) 2 * 100
  let ju-mor precision ((d-death-prob + d-mortality) * 1 * (num-sdogs / sd-init)) 2 * 100
  ifelse age > 24
  [ if random 100 < ad-mor + 1 [
    ask patch-here [
      ask min-n-of dsp patches with [ hh-id != 0 and dcc = 0] [distance myself ][
        set dcc pcc
        chk-av-dogs
        ]
      ]
    die
    ]
    ]
  [ if random 100 < ju-mor + 1 [
    die
    ]
    ]
end
to sd-birth
  move-to start-patch
  if week >= 37 and week <= 52 [
    if age > 52 [
      if (random-float 1 < (d-birth-prob * (sd-init / num-sdogs))) [
        hatch 1 [
          set status 1
          set shape "wolf"
          set color grey - 2
          set size 3
          set age 0
          setxy [ xcor ] of myself [ ycor ] of myself
          set start-patch patch-here
          set d-immune-status "ss"
          set d-days-incub-dog 0
          set d-days-shed-dog 0
          set d-days-shed-rod 0
          set d-days-incub-rod 0
          set sus sdog-addl-sus
          ]
        ]
      ]
    ]
end

to d-get-infected ;(and shed) agents have equal chances of getting infected with either serovar.
  let serovar-list []
  if d-immune-status = "ss" or d-immune-status = "rs" [
  let hp-dinf-dogs count dogs-here with [ status = 0 and d-immune-status = "sshed" ] + count dogs-here with [ status = 1 and d-immune-status = "sshed" ]
  let nhp-dinf-dogs sum [ count dogs-here with [ status = 0 and d-immune-status = "sshed" ] + count dogs-here with [ status = 1 and d-immune-status = "sshed" ]] of neighbors
  set hp-rl [ p-inf-rod ] of patch-here
  set hp-dl [ p-inf-dog ] of patch-here
  let sel-n n-of random 9 neighbors
  set nhp-rl sum [ p-inf-rod ] of sel-n
  set nhp-dl sum [ p-inf-dog ] of sel-n
  set patch-visited one-of patches with [ hh-id != 0 ] in-radius (1 + random 20 )
  let patch-visited-dinf-dogs 0
  ask patch-visited [
      set patch-visited-dinf-dogs sum [ count dogs-here with [ status = 0 and d-immune-status = "sshed" ] + count dogs-here with [ status = 1 and d-immune-status = "sshed" ]] of neighbors
      let sel-pvn n-of random 10 patches in-radius 1.5
      set patch-visited-n-rl sum [ p-inf-rod ] of sel-pvn
      set patch-visited-n-dl sum [ p-inf-dog ] of sel-pvn
      ]
    let dinf-dog-contact hp-dinf-dogs + random nhp-dinf-dogs + random patch-visited-dinf-dogs
    if dinf-dog-contact > 0 [
      set serovar-list lput "dog-serovar" serovar-list
      set d-trans-prob dinf-dog-contact * (dog-dog-transmission + (sus * dog-dog-transmission))
      ]
  ]
  if (d-immune-status = "ss" or d-immune-status = "sr") [
    let hp-rinf-dogs count dogs-here with [ status = 0 and d-immune-status = "sheds" ] + count dogs-here with [ status = 1 and d-immune-status = "sheds" ]
    let nhp-rinf-dogs sum [ count dogs-here with [ status = 0 and d-immune-status = "sheds" ] + count dogs-here with [ status = 1 and d-immune-status = "sheds" ]] of neighbors
    let patch-visited-rinf-dogs 0
    ask patch-visited [ set patch-visited-rinf-dogs sum [ count dogs-here with [ status = 0 and d-immune-status = "sheds" ] + count dogs-here with [ status = 1 and d-immune-status = "sheds" ]] of neighbors ]
    let rinf-dog-contact hp-rinf-dogs + random nhp-rinf-dogs + random patch-visited-rinf-dogs
    if rinf-dog-contact > 0 [
      set serovar-list lput "rodent-serovar" serovar-list
      set r-trans-prob rinf-dog-contact * (dog-dog-transmission + (sus * dog-dog-transmission))
      ]
    ]
  set serovar-list lput "patch-dog-serovar" serovar-list
  set serovar-list lput "patch-rodent-serovar" serovar-list
  set serovar-list shuffle serovar-list
  while [ empty? serovar-list = FALSE ] [
    let prob-infection item 0 serovar-list
    if (prob-infection = "dog-serovar") [ prob-infection-dogserovar ]
    if (prob-infection = "rodent-serovar") [ prob-infection-rodentserovar ]
    if (prob-infection = "patch-dog-serovar") [ prob-infection-pdogserovar ]
    if (prob-infection = "patch-rodent-serovar") [ prob-infection-prodentserovar ]
    set serovar-list remove-item 0 serovar-list
    ]
  ;----
  ; Dog shedding dog serovar
  if (d-immune-status = "si" or d-immune-status = "ri") and d-days-incub-dog < d-incub-pd-dog [
    set d-days-incub-dog d-days-incub-dog + 1
    ]
  if d-immune-status = "si" and d-days-incub-dog >= d-incub-pd-dog [
    set d-immune-status "sshed"
    set d-days-incub-dog 0
    ]
  if d-immune-status = "ri" and d-days-incub-dog >= d-incub-pd-dog [
    set d-immune-status "rshed"
    set d-days-incub-dog 0
  ]
  if (d-immune-status = "sshed" or d-immune-status = "rshed") and d-days-shed-dog <= 3 [
    set d-days-shed-dog d-days-shed-dog + 1
    set new-amt-shed (d-shed-init-dog * (d-days-shed-dog / 3))
    dog-shed-dogsero
    ]
  if (d-immune-status = "sshed" or d-immune-status = "rshed") and d-days-shed-dog > 3 and d-days-shed-dog <= 10 [
    set d-days-shed-dog d-days-shed-dog + 1
    set new-amt-shed d-shed-init-dog
    dog-shed-dogsero
    ]
  if (d-immune-status = "sshed" or d-immune-status = "rshed") and d-days-shed-dog > 10 [
    set d-days-shed-dog d-days-shed-dog + 1
    set new-amt-shed (d-shed-init-dog * (exp (- d-rate-decay-dog * (d-days-shed-dog - 10))))
    ifelse new-amt-shed < 100
    [ if d-immune-status = "sshed" [
      set d-immune-status "sr"
      ]
      if d-immune-status = "rshed" [
        set d-immune-status "rr"
      ]
      set d-days-recovered 0
      set d-days-shed-dog 0
    ]
    [ dog-shed-dogsero ]
    ]
  if d-immune-status = "sr" [
    if (d-days-recovered < 365) [
      set d-days-recovered d-days-recovered + 1
      ]
    if (d-days-recovered = 365) [
      set d-immune-status "ss"
      ]
    ]
   if d-immune-status = "rr" [
    if (d-days-recovered < 365) [
      set d-days-recovered d-days-recovered + 1
      ]
    if (d-days-recovered = 365) [
      set d-immune-status "rs"
      ]
    ]
  ; Dog shedding rodent serovar
  if (d-immune-status = "is" or d-immune-status = "ir") and d-days-incub-rod < d-incub-pd-rod [
    set d-days-incub-rod d-days-incub-rod + 1
  ]
  if d-immune-status = "is" and d-days-incub-rod >= d-incub-pd-rod [
    set d-immune-status "sheds"
    set d-days-incub-rod 0
    ]
  if d-immune-status = "ir" and d-days-incub-rod >= d-incub-pd-rod [
    set d-immune-status "shedr"
    set d-days-incub-rod 0
    ]

  if (d-immune-status = "sheds" or d-immune-status = "shedr") and d-days-shed-rod <= 3 [
    set d-days-shed-rod d-days-shed-rod + 1
    set new-amt-shed (d-shed-init-rod * (d-days-shed-rod / 3))
    dog-shed-rodsero
  ]
  if (d-immune-status = "sheds" or d-immune-status = "shedr") and d-days-shed-rod > 3 and d-days-shed-rod <= 10 [
    set d-days-shed-rod d-days-shed-rod + 1
    set new-amt-shed d-shed-init-rod
    dog-shed-rodsero
    ]
  if (d-immune-status = "sheds" or d-immune-status = "shedr") and d-days-shed-rod > 10 [
    set d-days-shed-rod d-days-shed-rod + 1
    set new-amt-shed (d-shed-init-rod * (exp (- d-rate-decay-rod * (d-days-shed-rod - 10))))
    ifelse new-amt-shed < 100
    [ if d-immune-status = "sheds" [
      set d-immune-status "rs"
      ]
      if d-immune-status = "shedr" [
        set d-immune-status "rr"
      ]
      set d-days-recovered 0 ]
    [ dog-shed-rodsero ]
    ]
end

to prob-infection-dogserovar
  if (d-immune-status = "ss") [    ;Can dog resistant to rod serovar can get infected by dog serovar?
    if random-float 1 < d-trans-prob [
      set d-immune-status "si"
      set d-trans-prob 0
      set cum-ann-dog-dl-inc cum-ann-dog-dl-inc + 1     ;added for sa
      ]
    ]
  if (d-immune-status = "rs") [
    if random-float 1 < d-trans-prob [
      set d-immune-status "ri"
      set d-trans-prob 0
      set cum-ann-dog-dl-inc cum-ann-dog-dl-inc + 1    ;added for sa
    ]
  ]
end
to prob-infection-pdogserovar
  if (d-immune-status = "ss" or d-immune-status = "rs") [                            ;Can rod resistant dogs can get infected with dog serovar?
    let trans-prob precision ((hp-dl + nhp-dl + patch-visited-n-dl) + (hp-dl + nhp-dl + patch-visited-n-dl * sus)) 3
    if random-float 1 < trans-prob [
      ifelse d-immune-status = "ss"
      [ set d-immune-status "si" ]
      [ set d-immune-status "ri" ]
      set cum-ann-dog-dl-inc cum-ann-dog-dl-inc + 1    ;added for sa
      ]
    ]
end
to prob-infection-rodentserovar
  if d-immune-status = "ss" or d-immune-status = "sr" [
    if random-float 1 < r-trans-prob [
      ifelse d-immune-status = "ss"
      [ set d-immune-status "is" ]
      [ set d-immune-status "ir" ]
      set d-death-prob (d-mortality * 0.1)
      set r-trans-prob 0
      set cum-ann-dog-rl-inc cum-ann-dog-rl-inc + 1    ;added for sa
      ]
    ]
end
to prob-infection-prodentserovar
  if d-immune-status = "ss" or d-immune-status = "sr" [
    let trans-prob hp-rl + nhp-rl + patch-visited-n-rl + (sus * hp-rl + nhp-rl + patch-visited-n-rl)
    if random-float 1 < trans-prob [
      ifelse d-immune-status = "ss"
      [ set d-immune-status "is" ]
      [ set d-immune-status "ir" ]
      set d-death-prob (d-mortality * 0.1)
      set cum-ann-dog-rl-inc cum-ann-dog-rl-inc + 1       ;added for sa
      ]
    ]
end
to dog-shed-dogsero
  ask patch-here [                                         ;40% leptospires are shed on the homepatch
    set e-amount-seroD e-amount-seroD + (0.4 * new-amt-shed)
    ]
  let cont-neigh-patches 1 + random 8
  ask n-of cont-neigh-patches neighbors [                  ;30% leptospires are shed on neighboring patches
    set e-amount-seroD e-amount-seroD + ((0.3 * new-amt-shed) / cont-neigh-patches)
    ]
  set cont-neigh-patches 1 + random 8
  ask patch-visited [
    ask n-of cont-neigh-patches patches in-radius 1.5 [    ;30% leptospires are shed on patch visited and its neighbors
      set e-amount-seroD e-amount-seroD + ((0.3 * new-amt-shed) / cont-neigh-patches)
      ]
    ]
end
to dog-shed-rodsero
  ask patch-here [                                        ;40% leptospires are shed on the homepatch
      set e-amount-seroR e-amount-seroR + (0.4 * new-amt-shed)
      ]
    let cont-neigh-patches 1 + random 8
    ask n-of cont-neigh-patches neighbors [               ;30% leptospires are shed on neighboring patches
      set e-amount-seroR e-amount-seroR + ((0.3 * new-amt-shed) / cont-neigh-patches)
    ]
    set cont-neigh-patches 1 + random 8
    ask patch-visited [
      ask n-of cont-neigh-patches patches in-radius 1.5 [  ;30% leptospires are shed on patch visited and its neighbors
        set e-amount-seroR e-amount-seroR + ((0.3 * new-amt-shed) / cont-neigh-patches)
    ]
  ]
end
to rod-shed-dogsero
  ask patch-here [                                          ;40% leptospires are shed on the homepatch
      set e-amount-seroD e-amount-seroD + (0.7 * new-amt-shed)
      ]
    let cont-neigh-patches 1 + random 8
    ask n-of cont-neigh-patches neighbors [                 ;30% leptospires are shed on neighboring patches
      set e-amount-seroD e-amount-seroD + ((0.3 * new-amt-shed) / cont-neigh-patches)
    ]
end
to rod-shed-rodsero
  ask patch-here [                                          ;40% leptospires are shed on the homepatch
      set e-amount-seroR e-amount-seroR + (0.7 * new-amt-shed)
      ]
    let cont-neigh-patches 1 + random 8
    ask n-of cont-neigh-patches neighbors [                 ;30% leptospires are shed on neighboring patches
      set e-amount-seroR e-amount-seroR + ((0.3 * new-amt-shed) / cont-neigh-patches)
    ]
end
;---------RODENTS------------
to r-die
  let Nr (count rodents)
  if r-age < 8 [
    if (random-float 1 < r-death-prob-juv * Nr / r-init) [
      die
      ]
    ]
  if r-age >= 8 [
    if (random-float 1 < r-death-prob-adult * Nr / r-init) [
      die
      ]
    ]
end
to r-birth
  let Nr (count rodents)
  if week > 12 and week <= 38 [
    let r-birth-p (random-float 1) * 4
    if (r-birth-p < r-birth-prob-low * r-init / Nr) [
      hatch 1                                                   ; hatch replacement rodents
      [ set shape "default"
        set color white
        set size 1
        let rr-homepatch one-of patches with [ hh-id > 0 ] in-radius 5
        setxy ([ pxcor ] of rr-homepatch) ([ pycor ] of rr-homepatch)
        set r-start-patch one-of patches in-radius 1.5
        move-to r-start-patch
        set r-age 0
        set r-immune-status "ss"
        set r-days-incub-rod 0
        set r-days-shed-rod 0
        set r-days-incub-dog 0
        set r-days-shed-dog 0
        ]
      ]
    ]
  if week <= 12 or week > 38 [
    if random-float 1 < 0.26 [
      if (random-float 1 < r-birth-prob-high * r-init / Nr) [
        hatch 1 [
          set shape "default"
          set color white
          set size 1
          let rr-homepatch one-of patches with [ hh-id > 0 ] in-radius 5
          setxy ([ pxcor ] of rr-homepatch) ([ pycor ] of rr-homepatch)
          set r-start-patch one-of patches in-radius 1.5
          move-to r-start-patch
          set r-age 0
          set r-immune-status "ss"
          set r-days-incub-rod 0
          set r-days-shed-rod 0
          set r-days-incub-dog 0
          set r-days-shed-dog 0
          ]
        ]
      ]
    ]
end
to r-get-infected
  let rserovar-list []
  if r-immune-status = "ss" [
    let hp-dinf-rods count rodents-here with [ r-immune-status = "sshed" or r-immune-status = "shedshed" ]
    set hp-rl [ p-inf-rod ] of patch-here
    set hp-dl [ p-inf-dog ] of patch-here
    let nhp-dinf-rods sum [ count rodents-here with [ r-immune-status = "sshed" or r-immune-status = "shedshed" ]] of neighbors
    let sel-n n-of random 9 neighbors
    set nhp-rl sum [ p-inf-rod ] of sel-n
    set nhp-dl sum [ p-inf-dog ] of sel-n
    set patch-visited one-of patches with [ hh-id != 0 ] in-radius (random r-home-range)
    let patch-visited-dinf-rods 0
    ask patch-visited [
      set patch-visited-dinf-rods sum [ count rodents-here with [ r-immune-status = "sshed" or r-immune-status = "shedshed" ]] of neighbors
      let sel-pvn n-of random 10 patches in-radius 1.5
      set patch-visited-n-rl sum [ p-inf-rod ] of sel-pvn
      set patch-visited-n-dl sum [ p-inf-dog ] of sel-pvn
      ]
    let dinf-rod-contact hp-dinf-rods + random nhp-dinf-rods + random patch-visited-dinf-rods
    if dinf-rod-contact > 0 [
      set rserovar-list lput "dog-serovar" rserovar-list
      set d-trans-prob dinf-rod-contact * rodent-rodent-transmission
      ]
    ]
    if r-immune-status = "ss" or r-immune-status = "sr" [
      let hp-rinf-rods count rodents-here with [ r-immune-status = "sheds" or r-immune-status = "shedi" or r-immune-status = "shedshed" or r-immune-status = "shedr" ]
      let nhp-rinf-rods sum [ count rodents-here with [ r-immune-status = "sheds" or r-immune-status = "shedi" or r-immune-status = "shedshed" or r-immune-status = "shedr" ]] of neighbors
      let patch-visited-rinf-rods 0
      ask patch-visited [ set patch-visited-rinf-rods sum [ count rodents-here with [ r-immune-status = "sheds" or r-immune-status = "shedi" or r-immune-status = "shedshed" or r-immune-status = "shedr" ] ] of neighbors ]
      let rinf-rod-contact hp-rinf-rods + random nhp-rinf-rods + random patch-visited-rinf-rods
      if rinf-rod-contact > 0 [
        set rserovar-list lput "rodent-serovar" rserovar-list
        set r-trans-prob rinf-rod-contact * (rodent-rodent-transmission)
        ]
      ]
    set rserovar-list lput "patch-dog-serovar" rserovar-list
    set rserovar-list lput "patch-rodent-serovar" rserovar-list
    set rserovar-list shuffle rserovar-list
    while [ empty? rserovar-list = FALSE ] [
      let prob-infection item 0 rserovar-list
      if (prob-infection = "dog-serovar") [ prob-infection-rdogserovar ]
      if (prob-infection = "rodent-serovar") [ prob-infection-rrodentserovar ]
      if (prob-infection = "patch-dog-serovar") [ prob-infection-rpdogserovar ]
      if (prob-infection = "patch-rodent-serovar") [ prob-infection-rprodentserovar ]
      set rserovar-list remove-item 0 rserovar-list
      ]
    ;!!!]
  ;----------
  ; Rodent shedding dog serovar
  if (r-immune-status = "si" or r-immune-status = "shedi") and r-days-incub-dog < r-incub-pd-dog [
    set r-days-incub-dog r-days-incub-dog + 1
  ]
  if (r-immune-status = "si" or r-immune-status = "shedi") and r-days-incub-dog >= r-incub-pd-dog [
    if r-immune-status = "si" [
      set r-immune-status "sshed"
    ]
    if r-immune-status = "shedi" [
      set r-immune-status "shedshed"
      ]
    set r-days-incub-dog 0
    ]
  if (r-immune-status = "sshed" or r-immune-status = "shedshed") and r-days-shed-dog <= 3 [
    set r-days-shed-dog r-days-shed-dog + 1
    set new-amt-shed (r-shed-init-dog * (r-days-shed-dog / 3))
    rod-shed-dogsero
    ]
  if (r-immune-status = "sshed" or r-immune-status = "shedshed") and r-days-shed-dog > 3 and r-days-shed-dog <= 10 [
    set r-days-shed-dog r-days-shed-dog + 1
    set new-amt-shed r-shed-init-dog
    rod-shed-dogsero
    ]
  if (r-immune-status = "sshed" or r-immune-status = "shedshed") and r-days-shed-dog > 10 [
    set r-days-shed-dog r-days-shed-dog + 1
    set new-amt-shed (r-shed-init-dog * (exp (- r-rate-decay-dog * (r-days-shed-dog - 10))))
    ifelse new-amt-shed < 100
    [ if r-immune-status = "sshed" [
      set r-immune-status "sr"
      ]
      if r-immune-status = "shedshed" [
        set r-immune-status "shedr"
        ]
      ]
    [ rod-shed-dogsero ]
    ]
  ; Rodent shedding rodent serovar
  if (r-immune-status = "is" or r-immune-status = "ir") and r-days-incub-rod < r-incub-pd-rod [
    set r-days-incub-rod r-days-incub-rod + 1
    ]

  if (r-immune-status = "is" or r-immune-status = "ir") and r-days-incub-rod >= r-incub-pd-rod [
    if r-immune-status = "is" [
      set r-immune-status "sheds"
      ]
    if r-immune-status = "ir" [
      set r-immune-status "shedr"
      ]
    set r-days-incub-rod 0
    ]
  ;!!!
  if (r-immune-status = "sheds" or r-immune-status = "shedi" or r-immune-status = "shedshed" or r-immune-status = "shedr") [
    set r-days-shed-rod r-days-shed-rod + 1
    if r-days-shed-rod >= 0 and r-days-shed-rod <= 3 [
      set new-amt-shed (r-shed-init-rod * (r-days-shed-rod / 3))
      rod-shed-rodsero
      ]
    if r-days-shed-rod > 3 and r-days-shed-rod <= 10 [
      set new-amt-shed r-shed-init-rod
      rod-shed-rodsero
      ]
    if r-days-shed-rod > 10 [
      set new-amt-shed (r-shed-init-rod * (exp (- r-rate-decay-rod * (r-days-shed-rod - 10))))
      ifelse new-amt-shed < 100
      [ set r-days-shed-rod random -31 ]
      [ rod-shed-rodsero ]
    ]
  ]

end
to prob-infection-rdogserovar
  if r-immune-status = "ss" [
    if (random-float 1 < d-trans-prob) [
      set r-immune-status "si"
      set d-trans-prob 0
      set cum-ann-rod-dl-inc cum-ann-rod-dl-inc + 1                      ;added for sa
      ]
    ]
  if r-immune-status = "sheds" [
    if (random-float 1 < d-trans-prob) [
      set r-immune-status "shedi"
      set d-trans-prob 0
      set cum-ann-rod-dl-inc cum-ann-rod-dl-inc + 1                      ;added for sa
    ]
  ]
end
to prob-infection-rpdogserovar
  if r-immune-status = "ss" [
    if (random-float 1 < hp-dl + nhp-dl + patch-visited-n-dl) [
      set r-immune-status "si"
      set cum-ann-rod-dl-inc cum-ann-rod-dl-inc + 1                      ;added for sa
      ]
    ]
  if r-immune-status = "sheds" [
    if (random-float 1 < hp-dl + nhp-dl + patch-visited-n-dl) [
      set r-immune-status "shedi"
      set cum-ann-rod-dl-inc cum-ann-rod-dl-inc + 1                      ;added for sa
      ]
    ]
end
to prob-infection-rrodentserovar
  if r-immune-status = "ss" [
    if (random-float 1 < r-trans-prob) [
      set r-immune-status "is"
      set r-trans-prob 0
      set cum-ann-rod-rl-inc cum-ann-rod-rl-inc + 1                       ;added for sa
      ]
    ]
  if r-immune-status = "sr" [
    if (random-float 1 < r-trans-prob) [
      set r-immune-status "ir"
      set r-trans-prob 0
      set cum-ann-rod-rl-inc cum-ann-rod-rl-inc + 1                        ;added for sa
      ]
    ]
end
to prob-infection-rprodentserovar
  if r-immune-status = "ss" [
   if (random-float 1 < hp-rl + nhp-rl + patch-visited-n-rl) [
      set r-immune-status "is"
      set cum-ann-rod-rl-inc cum-ann-rod-rl-inc + 1                          ;added for sa
      ]
    ]
  if r-immune-status = "sr" [
   if (random-float 1 < hp-rl + nhp-rl + patch-visited-n-rl) [
      set r-immune-status "ir"
      set cum-ann-rod-rl-inc cum-ann-rod-rl-inc + 1                          ;added for sa
      ]
    ]
end
;---------- HUMANS -------------
to h-die
  ifelse (h-immune-status = "si" or h-immune-status = "is")
  [ if random-float 1 < ((h-death-prob * 1.1) * (count humans / h-init)) [ die ] ]
  [ if random-float 1 < (h-death-prob * (count humans / h-init)) [ die ] ]
end
to h-birth
  if (random-float 1 < h-birth-prob * (h-init / count humans))[
    hatch 1 [
      set shape "person"
      set color blue
      set size 2
      let h-HH-id random 150
      let id (h-HH-id + 1)
      let h-homepatch one-of patches with [ hh-id = id ]
      setxy [ pxcor ] of h-homepatch [ pycor ] of h-homepatch
      set h-immune-status "ss"
      set h-days-inf-dog 0
      set h-days-inf-rod 0
      ]
    ]
end
;--------------------------------------------------
to h-get-infected
  if h-immune-status = "ss" [
    let p-inf-dog-s 0
    let p-inf-dog-hp p-inf-dog / 100
    let sel-n n-of random 10 patches in-radius 1.5
    let p-inf-dog-hha sum [ p-inf-dog / 100 ] of sel-n
    let sel-slum-patch one-of patches with [ hh-id != 0 ] in-radius 50
    ask sel-slum-patch [
      let sel-v n-of random 10 patches in-radius 1.5
      set p-inf-dog-s sum [ p-inf-dog / 100 ] of sel-v
     ]
    let cum-prob-inf-dogsero p-inf-dog-hp + p-inf-dog-hha + p-inf-dog-s
    if random-float 1 < cum-prob-inf-dogsero [
      set h-immune-status "si"
      ;set cum-ann-human-dl-inc cum-ann-human-dl-inc + 1
      if (week < 53) [ set cum-ann-human-dl-inc cum-ann-human-dl-inc + 1 ]          ;;sa remove if week , 53??
      set h-days-inf-dog 2 + random 29
      ]
    ]
  if h-immune-status = "ss" [
    let p-inf-rod-s 0
    let p-inf-rod-hp p-inf-rod / 100
    let sel-nn n-of random 10 patches in-radius 1.5
    let p-inf-rod-hha sum [ p-inf-rod / 100 ] of sel-nn
    let sel-slum-patch one-of patches with [ hh-id != 0 ] in-radius 50
    ask sel-slum-patch [
      let sel-vv n-of random 10 patches in-radius 1.5
      set p-inf-rod-s sum [ p-inf-rod / 100 ] of sel-vv
     ]
    let cum-prob-inf-rodsero p-inf-rod-hp + p-inf-rod-hha + p-inf-rod-s
    if (random-float 1 < cum-prob-inf-rodsero) [ ;(p-inf-rod / 100)) [
      set h-immune-status "is"
      ;set cum-ann-human-dl-inc cum-ann-human-dl-inc + 1
      if (week < 53) [ set cum-ann-human-rl-inc cum-ann-human-rl-inc + 1 ]
      set h-days-inf-rod 2 + random 29
      ]
    ]
;end
;to h-shed
  if h-immune-status = "si" and h-days-inf-dog < 43 [
    set h-days-inf-dog h-days-inf-dog + 1
    ]
  if h-immune-status = "si" and h-days-inf-dog = 43 [
    set h-immune-status "sr"
    ]
  if h-immune-status = "is" and h-days-inf-rod < 43 [
    set h-days-inf-rod h-days-inf-rod + 1
    ]
  if h-immune-status = "is" and h-days-inf-rod = 43 [
    set h-immune-status "rs"
    ]
end
to e-decay
  set p-inf-rod (e-amount-seroR * 0.01 / 10 ^ 7)
  set p-inf-dog (e-amount-seroD * 0.01 / 10 ^ 7)
  set e-amount-seroD e-amount-seroD * decay-factor
  set e-amount-seroR e-amount-seroR * decay-factor
  if e-amount-seroD < 1000 [
    set e-amount-seroD 0
    ]
  if e-amount-seroR < 1000 [
    set e-amount-seroR 0
    ]
 end

to-report year
  report ceiling ((ticks + 1)/ 52)
end
to-report week
   ifelse year = 1
  [ report (ticks + 1) ]
  [ report ceiling ((ticks - (year - 1) * 52) + 1) ]
end
to-report slum-area  ; total dog supporting patches
  report count patches with [ hh-id != 0 ]
end
to-report ini-dogs                                                                     ;max number of dogs ~ carrying capacity(k) ~ 2500 per sq km
  report round (sum [num-humans] of patches with [ hh-id > 0 ] / num-humans-per-dog)   ;using human:dog ratio
end
to-report pcc
  report precision (ini-dogs / count patches with [ hh-id != 0 ]) 3
end
to-report h-init
  report (sum [num-humans] of patches with [ hh-id > 0 ])
end
to-report r-init
  report num-households * mean-num-rodents-perhh
end
to-report od-init                                                                     ;1:1 owned dog:stray dog ratio
  report round (ini-dogs / 2)
end
to-report sd-init
  report round (ini-dogs / 2)
end
to-report h-birth-prob
  report 0.000266
end
to-report h-death-prob
  report 0.000266
end
to-report d-birth-prob
  report 0.1480
end
to-report d-mortality
  report 0.0228
end
to-report od-init-prev
  report 0.04
end
to-report sd-init-prev
  report 0.04
end
to-report r-init-prev
  report 0.10
end
to-report sdog-addl-sus
  report 0.5
end
to-report r-death-prob-juv
  report 0.0830
end
to-report r-death-prob-adult
  report 0.0957
end
to-report r-birth-prob-high
  report 0.6027
end
to-report r-birth-prob-low
  report 0.2063
end
to-report r-incub-pd-dog
  report 7 + random 8
end
to-report r-incub-pd-rod
  report 7 + random 8
end
to-report d-incub-pd-dog
  report 3 + random 12
end
to-report d-incub-pd-rod
  report 3 + random 19
end
to-report r-shed-init-dog
 report abs ((random-normal 6100000 1500000) * 7.58)
end
to-report r-shed-init-rod
 report abs ((random-normal 6100000 1500000) * 7.58)
end
to-report d-shed-init-dog
 report abs ((random-normal 59000 10000) * 900)
end
to-report d-shed-init-rod
 report abs((random-normal 59000 10000) * 900)
end
to-report d-rate-decay-dog
 report (0.15 + random-float 0.2)
end
to-report d-rate-decay-rod
 report (0.3 + random-float 0.4)
end
to-report r-rate-decay-dog
 report (0.3 + random-float 0.4)
end
to-report r-rate-decay-rod
 report (0.15 + random-float 0.2)
end
to-report k-dogs
  report round (((count patches with [ hh-id != 0 ] * 49) / 1000000) * 2300)
end
to-report dsp                                     ;number of dog supporting patches required per dog
  report round (slum-area / k-dogs)
end
to-report r-home-range
  report 3
end
to-report num-sdogs
  report count dogs with [ status = 1 ]
end
to-report num-odogs
  report count dogs with [ status = 0 ]
end
to-report human-dl-inc
  report precision (count humans with [ h-immune-status = "si" ] / count humans) 3
end
to-report human-rl-inc
  report precision (count humans with [ h-immune-status = "is" ] / count humans) 3
end
to-report human-dl-pre
  report precision (count humans with [ h-immune-status = "sr" ] / count humans) 3
end
to-report human-rl-pre
  report precision (count humans with [ h-immune-status = "rs" ] / count humans) 3
end
to-report sdog-dl-pre
  report precision (count dogs with [ status = 1 and d-immune-status = "sr" ] / num-sdogs) 3
end
to-report sdog-rl-pre
  report precision (count dogs with [ status = 1 and d-immune-status = "rs" ] / num-sdogs) 3
end
to-report odog-dl-pre
  report precision (count dogs with [ status = 0 and d-immune-status = "sr" ] / num-odogs) 3
end
to-report odog-rl-pre
  report precision (count dogs with [ status = 0 and d-immune-status = "rs" ] / num-odogs) 3
end
to-report rodent-rl-pre
  report precision (count rodents with [ r-immune-status = "is" or r-immune-status = "sheds" or r-immune-status = "shedi" or r-immune-status = "shedshed" or r-immune-status = "shedr" or r-immune-status = "ir"] / count rodents) 3
end
to-report rodent-dl-pre
  report precision (count rodents with [ r-immune-status = "shedi" or r-immune-status = "shedshed" or r-immune-status = "sshed" or r-immune-status = "si" ] / count rodents) 3
end
to-report avg-annual-human-pop
  report (cum-human-pop / 12)
end
to-report avg-annual-dog-pop
  report (cum-dog-pop / 12)
end
to-report avg-annual-rodent-pop
  report (cum-rodent-pop / 12)
end
@#$#@#$#@
GRAPHICS-WINDOW
201
10
781
591
-1
-1
4.0
1
10
1
1
1
0
0
0
1
0
142
0
142
0
0
1
ticks
30.0

BUTTON
15
10
90
43
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
123
10
187
43
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
788
400
1009
528
Owned Dog Abundance
weeks
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"owned dogs" 1.0 0 -16777216 true "" "plot num-odogs"

PLOT
790
135
1008
263
Rodent Abundance
weeks
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"rodents" 1.0 0 -16777216 true "" "plot count rodents"

PLOT
925
10
1159
130
Infected Patch Prevalence
NIL
NIL
0.0
10.0
0.0
0.1
true
true
"" ""
PENS
"SeroD" 1.0 0 -2674135 true "" "plot (count patches with [p-inf-dog > 0.0025] / count patches)"
"SeroR" 1.0 0 -13345367 true "" "plot (count patches with [p-inf-rod > 0.0025] / count patches)"

MONITOR
790
14
847
59
Year
year
17
1
11

MONITOR
861
15
916
60
Week
week
17
1
11

PLOT
1329
131
1566
261
Human_Lepto_incidence
NIL
NIL
0.0
1.0
0.0
0.001
true
true
"" ""
PENS
"SeroD" 1.0 0 -2674135 true "" ""
"SeroR" 1.0 0 -13345367 true "" ""

MONITOR
1272
324
1413
369
SeroD incidence in humans
human-dl-inc
17
1
11

MONITOR
1272
274
1415
319
SeroR incidence in humans
human-rl-inc
17
1
11

PLOT
1330
386
1565
506
Human_Lepto_prevalence
NIL
NIL
0.0
10.0
0.0
0.001
true
true
"" ""
PENS
"SeroD" 1.0 0 -2674135 true "" ""
"SeroR" 1.0 0 -13345367 true "" ""

MONITOR
1443
515
1590
560
SeroD prevalence in humans
human-dl-pre
17
1
11

MONITOR
1282
517
1431
562
SeroR prevalence in humans
human-rl-pre
17
1
11

PLOT
1021
397
1261
527
OwnedDog_Lepto_prevalence
NIL
NIL
0.0
10.0
0.0
0.3
true
true
"" ""
PENS
"SeroD" 1.0 0 -2674135 true "" ""
"SeroR" 1.0 0 -13345367 true "" ""

PLOT
1017
135
1260
267
Rodents_Lepto_prevalence
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"SeroD" 1.0 0 -2674135 true "" ""
"SeroR" 1.0 0 -13345367 true "" ""

PLOT
790
273
1010
393
Stray Dog Abundance
weeks
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"stray dogs" 1.0 0 -16777216 true "" "plot num-sdogs"

MONITOR
1173
43
1256
88
NIL
rodent-rl-pre
17
1
11

MONITOR
1425
329
1604
374
Human SeroD incidence per 10000
round (ann-human-dl-inc-per10000)
17
1
11

MONITOR
1423
276
1603
321
Human SeroR incidence per 10000
round (ann-human-rl-inc-per10000)
17
1
11

CHOOSER
10
543
182
588
Output_file?
Output_file?
"YES" "NO"
0

MONITOR
1173
87
1258
132
NIL
rodent-dl-pre
17
1
11

PLOT
1019
270
1261
394
StrayDog_Lepto_prevalence
NIL
NIL
0.0
10.0
0.0
0.3
true
true
"" ""
PENS
"SeroD" 1.0 0 -2674135 true "" ""
"SeroR" 1.0 0 -13345367 true "" ""

SLIDER
11
472
183
505
decay-factor
decay-factor
0
1
0.8
0.01
1
NIL
HORIZONTAL

SLIDER
12
385
184
418
dog-dog-transmission
dog-dog-transmission
0
1
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
12
431
185
464
rodent-rodent-transmission
rodent-rodent-transmission
0
1
0.1
0.01
1
NIL
HORIZONTAL

PLOT
1636
258
1855
386
Number of humans per household
NIL
NIL
0.0
15.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [ count humans-here ] of patches with [ hh-id > 0 ]"

MONITOR
966
539
1060
584
Dog abundance
num-odogs + num-sdogs
17
1
11

MONITOR
83
198
182
243
slum area in km2
((count patches with [ pcolor != black ]) * 49) / 1000000
2
1
11

SLIDER
14
69
186
102
num-households
num-households
50
500
150.0
50
1
NIL
HORIZONTAL

SLIDER
13
111
185
144
hh-area
hh-area
5
50
30.0
5
1
NIL
HORIZONTAL

SLIDER
10
263
182
296
num-humans-per-dog
num-humans-per-dog
1
50
3.0
1
1
NIL
HORIZONTAL

SLIDER
10
305
185
338
mean-num-rodents-perhh
mean-num-rodents-perhh
0
50
9.5
0.5
1
NIL
HORIZONTAL

PLOT
1694
10
1879
142
rodent age distribution
age in weeks
abundance
0.0
60.0
0.0
20.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [r-age] of rodents"

SLIDER
11
152
183
185
community-size
community-size
5
25
20.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

The purpose of this agent-based model is to simulate the multi-host, multi-strain serovar dynamics of leptospirosis. The overall goal is to support the design of meaningful interventions for the disease in marginalized, high density community consisting of dogs, rodents, and humans.

## HOW IT WORKS

MHMSLeptoDy has four entities: rodents, dogs, humans, and patches. Rodents, dogs, and humans are modeled as individuals occupying the patches.
The model landscape represents one square kilometer area (143 x 143 patches, each patch equals 49 square meters), though the effective area depends on three user-specified parameters: ‘num-households’ (number of households), ‘hh-area’ (households and their surrounding patches) and ‘community-area’ (area of influence of households) 
During each time step (week):
1.	Dogs and rodents execute three processes: ‘die’, ‘birth’ and ‘age’.
2.	Humans execute ‘die’ and ‘birth’.
3.	After 5 years (ticks = 260), leptospira dynamics (‘inf-dynamics’) is executed 7 times every time step. Susceptible hosts have a probability of being directly infected with either SeroD or SeroR (dog-to-dog and rodent-to-rodent) or indirectly through the environment (contact with contaminated patches).
4.	Infected rodents and dogs remain latently infected (not infectious) during the ‘incubation period’, followed by the infectious phase when leptospires are shed in urine (‘shedding’).   Humans infected with leptospira serovar are not infectious, and directly proceed to the recovered phase. 
5.	Rodents infected with rodent serovar (SeroR) remain persistently infected and continue to shed leptospires intermittently, whereas rodents recovering from dog serovar (SeroD) infection have lifelong immunity against SeroD. Dogs recovering from dog serovar (SeroD) infection have immunity against SeroD for a year, but dogs that recover from rodent serovar (SeroR) infection have lifelong immunity against SeroR.
6.	Leptospires present on the model patches decay. This process is also run 7 times every time-step. 
7.	Serovar-specific prevalence in calculated for each host. Additionally, serovar-specific incidence is calculated for humans. 
 

## HOW TO USE IT

Households and humans: The user specifies the number of households desired, the ‘hh-area’ (households and their surrounding patches) and ‘community-area’ (area of influence of households). All patches are clear of contamination with leptospires. 
Human agents are associated with household patches. Each household patch is initiated with a mean of 4 humans (range 1 - 11) [Mason, 2015]. Distribution of human agents is maintained within this range throughout the model simulation.
Dogs: The carrying capacity of dogs is set at 2500 per square kilometer (extrapolated from Acosta-Jamett, 2010). The user defines the human: dog ratio (num-humans-per-dog) in the community.  Dogs are essentially free-roaming, but some are closely associated with households (hence "owned") and potentially accessible for interventions. Dogs not associated with households are designated as "stray" dogs - these dogs are still dependent on the households (food, garbage, shelter) and so remain in the ‘community-area’. 
Owned dogs have a household patch (yellow) as their 'home-patch', while stray dogs can have any non-household patch (dark brown and light brown) as their 'home-patch'. Owned dogs are distributed based on household dog ownership data from Chile: 47% of households do not own dogs, 27% own one dog, 11% own two dogs, 8% own three dogs, 5% own four dogs, and 2% own five dogs [Acosta-Jamet, 2010].
Rodents: The user defines the number of rodents per household in the community and the rodents are randomly distributed across ‘hh-area’ patches in the community area. 
Transmission parameters: The user defines the probability of direct transmission from rodent-to-rodent and from dog-to-dog. The proportion of leptospires surviving each day is also user-defined (decay-factor). 

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Model Validation - Baseline Model 062316" repetitions="12" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>GO</go>
    <timeLimit steps="520"/>
    <metric>count sdogs</metric>
    <metric>count sdogs with [d-SIR-dog-Shed = TRUE] / count sdogs</metric>
    <metric>count sdogs with [d-SIR-rod-Shed = TRUE] / count sdogs</metric>
    <metric>count sdogs with [(d-SIR-dog-Shed = FALSE) and (d-SIR-rod-Shed = FALSE)] / count sdogs</metric>
    <metric>count odogs</metric>
    <metric>count odogs with [d-SIR-dog-Shed = TRUE] / count odogs</metric>
    <metric>count odogs with [d-SIR-rod-Shed = TRUE] / count odogs</metric>
    <metric>count odogs with [(d-SIR-dog-Shed = FALSE) and (d-SIR-rod-Shed = FALSE)] / count odogs</metric>
    <metric>count humans</metric>
    <metric>h-incident-case-seroR</metric>
    <metric>h-incident-case-seroD</metric>
    <metric>count humans with [h-SIR-rod-I = TRUE]</metric>
    <metric>count humans with [h-SIR-dog-I = TRUE]</metric>
    <metric>count humans with [h-SIR-rod-I = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-dog-I = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-rod-R = TRUE]</metric>
    <metric>count humans with [h-SIR-dog-R = TRUE]</metric>
    <metric>count humans with [h-SIR-rod-R = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-dog-R = TRUE] / count humans</metric>
    <metric>count rodents</metric>
    <metric>count rodents with [r-SIR-dog-Shed = TRUE] / count rodents</metric>
    <metric>count rodents with [r-SIR-rod-Shed = TRUE] / count rodents</metric>
    <metric>count rodents with [(r-SIR-dog-Shed = FALSE) and (r-SIR-rod-Shed = FALSE)] / count rodents</metric>
    <metric>count patches with [e-amount-seroR &gt; 10000] / count patches</metric>
    <metric>count patches with [e-amount-seroR &gt; 100000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 10000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 100000] / count patches</metric>
    <metric>count patches with [e-contaminated-from-dog-d = TRUE] / count patches</metric>
    <metric>count patches with [e-contaminated-from-dog-r = TRUE] / count patches</metric>
    <metric>count patches with [e-contaminated-from-rod-d = TRUE] / count patches</metric>
    <metric>count patches with [e-contaminated-from-rod-r = TRUE] / count patches</metric>
    <enumeratedValueSet variable="r-init">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="od-init">
      <value value="225"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h-init">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sd-init">
      <value value="225"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Model Validation - Baseline Model 062316_V2" repetitions="12" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>GO</go>
    <timeLimit steps="520"/>
    <metric>count sdogs</metric>
    <metric>count sdogs with [d-SIR-dog-Shed = TRUE] / count sdogs</metric>
    <metric>count sdogs with [d-SIR-rod-Shed = TRUE] / count sdogs</metric>
    <metric>count sdogs with [(d-SIR-dog-Shed = FALSE) and (d-SIR-rod-Shed = FALSE)] / count sdogs</metric>
    <metric>count odogs</metric>
    <metric>count odogs with [d-SIR-dog-Shed = TRUE] / count odogs</metric>
    <metric>count odogs with [d-SIR-rod-Shed = TRUE] / count odogs</metric>
    <metric>count odogs with [(d-SIR-dog-Shed = FALSE) and (d-SIR-rod-Shed = FALSE)] / count odogs</metric>
    <metric>count humans</metric>
    <metric>h-incident-case-seroR</metric>
    <metric>h-incident-case-seroD</metric>
    <metric>count humans with [h-SIR-rod-I = TRUE]</metric>
    <metric>count humans with [h-SIR-dog-I = TRUE]</metric>
    <metric>count humans with [h-SIR-rod-I = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-dog-I = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-rod-R = TRUE]</metric>
    <metric>count humans with [h-SIR-dog-R = TRUE]</metric>
    <metric>count humans with [h-SIR-rod-R = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-dog-R = TRUE] / count humans</metric>
    <metric>count rodents</metric>
    <metric>count rodents with [r-SIR-dog-Shed = TRUE] / count rodents</metric>
    <metric>count rodents with [r-SIR-rod-Shed = TRUE] / count rodents</metric>
    <metric>count rodents with [(r-SIR-dog-Shed = FALSE) and (r-SIR-rod-Shed = FALSE)] / count rodents</metric>
    <metric>count patches with [e-amount-seroR &gt; 10000] / count patches</metric>
    <metric>count patches with [e-amount-seroR &gt; 100000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 10000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 100000] / count patches</metric>
    <metric>count patches with [e-contaminated-from-dog-d = TRUE] / count patches</metric>
    <metric>count patches with [e-contaminated-from-dog-r = TRUE] / count patches</metric>
    <metric>count patches with [e-contaminated-from-rod-d = TRUE] / count patches</metric>
    <metric>count patches with [e-contaminated-from-rod-r = TRUE] / count patches</metric>
    <enumeratedValueSet variable="r-init">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="od-init">
      <value value="225"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h-init">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sd-init">
      <value value="225"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Model Validation - Baseline Model 070416" repetitions="52000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>GO</go>
    <timeLimit steps="600"/>
    <metric>count sdogs</metric>
    <metric>count sdogs with [d-SIR-dog-Shed = TRUE] / count sdogs</metric>
    <metric>count sdogs with [d-SIR-rod-Shed = TRUE] / count sdogs</metric>
    <metric>count sdogs with [(d-SIR-dog-Shed = FALSE) and (d-SIR-rod-Shed = FALSE)] / count sdogs</metric>
    <metric>count odogs</metric>
    <metric>count odogs with [d-SIR-dog-Shed = TRUE] / count odogs</metric>
    <metric>count odogs with [d-SIR-rod-Shed = TRUE] / count odogs</metric>
    <metric>count odogs with [(d-SIR-dog-Shed = FALSE) and (d-SIR-rod-Shed = FALSE)] / count odogs</metric>
    <metric>count humans</metric>
    <metric>h-incident-case-seroR</metric>
    <metric>h-incident-case-seroD</metric>
    <metric>count humans with [h-SIR-rod-I = TRUE]</metric>
    <metric>count humans with [h-SIR-dog-I = TRUE]</metric>
    <metric>count humans with [h-SIR-rod-I = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-dog-I = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-rod-R = TRUE]</metric>
    <metric>count humans with [h-SIR-dog-R = TRUE]</metric>
    <metric>count humans with [h-SIR-rod-R = TRUE] / count humans</metric>
    <metric>count humans with [h-SIR-dog-R = TRUE] / count humans</metric>
    <metric>count rodents</metric>
    <metric>count rodents with [r-SIR-dog-Shed = TRUE] / count rodents</metric>
    <metric>count rodents with [r-SIR-rod-Shed = TRUE] / count rodents</metric>
    <metric>count rodents with [(r-SIR-dog-Shed = FALSE) and (r-SIR-rod-Shed = FALSE)] / count rodents</metric>
    <metric>count patches with [e-amount-seroR &gt; 1000] / count patches</metric>
    <metric>count patches with [e-amount-seroR &gt; 10000] / count patches</metric>
    <metric>count patches with [e-amount-seroR &gt; 100000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 1000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 10000] / count patches</metric>
    <metric>count patches with [e-amount-seroD &gt; 100000] / count patches</metric>
    <metric>sum [e-amount-seroD] of patches</metric>
    <metric>sum [e-amount-seroD-d] of patches</metric>
    <metric>sum [e-amount-seroD-r] of patches</metric>
    <metric>sum [e-amount-seroR] of patches</metric>
    <metric>sum [e-amount-seroR-d] of patches</metric>
    <metric>sum [e-amount-seroR-r] of patches</metric>
    <enumeratedValueSet variable="r-init">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="od-init">
      <value value="155"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h-init">
      <value value="615"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sd-init">
      <value value="155"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="l-d-env" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="decay-factor">
      <value value="0.8"/>
      <value value="0.4"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="h-init">
      <value value="615"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r-init">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Output_file?">
      <value value="&quot;YES&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="od-init">
      <value value="155"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sd-init">
      <value value="160"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
